@@ -380,7 +380,7 @@ sub amdenergy_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -509,13 +509,16 @@ sub amdenergy_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	my $plots_per_list_item = 1;
 	foreach my $k (sort keys %{$amdenergy->{list}}) {
@@ -712,7 +715,7 @@ sub amdenergy_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			$large_plot ? () : @{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -734,7 +737,7 @@ sub amdenergy_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				$large_plot ? () : @{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -752,8 +755,8 @@ sub amdenergy_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * $plots_per_list_item + $n_plot], IMG => $IMG[$e * $plots_per_list_item + $n_plot]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
