@@ -184,13 +184,13 @@ sub ftp_update {
 					if($cmd eq "RETR") {
 						if($code =~ /^2../) {
 							$retr++;
-							$bytes_down += int($bytes);
+							$bytes_up += int($bytes);
 						}
 					}
 					if($cmd =~ /(STOR|STOU)/) {
 						if($code =~ /^2../) {
 							$stor++;
-							$bytes_up += int($bytes);
+							$bytes_down += int($bytes);
 						}
 					}
 					if($cmd =~ /(MKD|XMKD)/) {
@@ -222,11 +222,11 @@ sub ftp_update {
 				if(/^$date /) {
 					if(/ OK DOWNLOAD: .*?, (\d+) bytes, /) {
 						$retr++;
-						$bytes_down += int($1);
+						$bytes_up += int($1);
 					}
 					if(/ OK UPLOAD: .*?, (\d+) bytes, /) {
 						$stor++;
-						$bytes_up += int($1);
+						$bytes_down += int($1);
 					}
 					if(/ OK MKDIR: /) {
 						$mkd++;
@@ -256,11 +256,11 @@ sub ftp_update {
 				if(/^$date /) {
 					if(/ \[NOTICE\] .*? downloaded  \((\d+) bytes,.*?/) {
 						$retr++;
-						$bytes_down += int($1);
+						$bytes_up += int($1);
 					}
 					if(/ \[NOTICE\] .*? uploaded  \((\d+) bytes,.*?/) {
 						$stor++;
-						$bytes_up += int($1);
+						$bytes_down += int($1);
 					}
 					if(/ \[DEBUG\] Command \[mkd\] /) {
 						$mkd++;
@@ -312,7 +312,7 @@ sub ftp_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -401,13 +401,16 @@ sub ftp_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	my $IMG1 = $u . $package . "1." . $tf->{when} . ".$imgfmt_lc";
 	my $IMG2 = $u . $package . "2." . $tf->{when} . ".$imgfmt_lc";
@@ -432,16 +435,16 @@ sub ftp_cgi {
 		push(@output, "    <tr>\n");
 		push(@output, "    <td>\n");
 	}
-	push(@tmp, "LINE2:retr#44EE44:Files downloaded (RETR)");
-	push(@tmp, "GPRINT:retr:LAST: Current\\: %3.0lf");
-	push(@tmp, "GPRINT:retr:AVERAGE:   Average\\: %3.0lf");
-	push(@tmp, "GPRINT:retr:MIN:   Min\\: %3.0lf");
-	push(@tmp, "GPRINT:retr:MAX:   Max\\: %3.0lf\\n");
-	push(@tmp, "LINE2:stor#4444EE:Files uploaded (STOR)");
+	push(@tmp, "LINE2:stor#44EE44:Files uploaded (STOR)");
 	push(@tmp, "GPRINT:stor:LAST:   Current\\: %3.0lf");
 	push(@tmp, "GPRINT:stor:AVERAGE:   Average\\: %3.0lf");
 	push(@tmp, "GPRINT:stor:MIN:   Min\\: %3.0lf");
 	push(@tmp, "GPRINT:stor:MAX:   Max\\: %3.0lf\\n");
+	push(@tmp, "LINE2:retr#4444EE:Files downloaded (RETR)");
+	push(@tmp, "GPRINT:retr:LAST: Current\\: %3.0lf");
+	push(@tmp, "GPRINT:retr:AVERAGE:   Average\\: %3.0lf");
+	push(@tmp, "GPRINT:retr:MIN:   Min\\: %3.0lf");
+	push(@tmp, "GPRINT:retr:MAX:   Max\\: %3.0lf\\n");
 	push(@tmp, "LINE2:mkd#EEEE44:Dirs created (MKD)");
 	push(@tmp, "GPRINT:mkd:LAST:      Current\\: %3.0lf");
 	push(@tmp, "GPRINT:mkd:AVERAGE:   Average\\: %3.0lf");
@@ -462,8 +465,8 @@ sub ftp_cgi {
 	push(@tmp, "GPRINT:mlsd:AVERAGE:   Average\\: %3.0lf");
 	push(@tmp, "GPRINT:mlsd:MIN:   Min\\: %3.0lf");
 	push(@tmp, "GPRINT:mlsd:MAX:   Max\\: %3.0lf\\n");
-	push(@tmpz, "LINE2:retr#44EE44:Files downloaded (RETR)");
-	push(@tmpz, "LINE2:stor#4444EE:Files uploaded (STOR)");
+	push(@tmpz, "LINE2:stor#44EE44:Files uploaded (STOR)");
+	push(@tmpz, "LINE2:retr#4444EE:Files downloaded (RETR)");
 	push(@tmpz, "LINE2:mkd#EEEE44:Dirs created (MKD)");
 	push(@tmpz, "LINE2:rmd#EE4444:Dirs deleted (RMD)");
 	push(@tmpz, "LINE2:dele#EE44EE:Files deleted (DELE)");
@@ -488,7 +491,7 @@ sub ftp_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$colors->{graph_colors}},
 		"DEF:retr=$rrd:ftp_retr:AVERAGE",
@@ -515,7 +518,7 @@ sub ftp_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:retr=$rrd:ftp_retr:AVERAGE",
@@ -536,8 +539,8 @@ sub ftp_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG1z, IMG => $IMG1) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -595,7 +598,7 @@ sub ftp_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -620,7 +623,7 @@ sub ftp_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -640,8 +643,8 @@ sub ftp_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG2z, IMG => $IMG2) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -657,18 +660,18 @@ sub ftp_cgi {
 	undef(@tmp);
 	undef(@tmpz);
 	undef(@CDEF);
-	push(@tmp, "AREA:B_up#44EE44:Upload");
-	push(@tmp, "AREA:B_dn#4444EE:Download");
-	push(@tmp, "AREA:B_dn#4444EE:");
-	push(@tmp, "AREA:B_up#44EE44:");
-	push(@tmp, "LINE1:B_dn#0000EE");
-	push(@tmp, "LINE1:B_up#00EE00");
-	push(@tmpz, "AREA:B_up#44EE44:Upload");
-	push(@tmpz, "AREA:B_dn#4444EE:Download");
-	push(@tmpz, "AREA:B_dn#4444EE:");
-	push(@tmpz, "AREA:B_up#44EE44:");
-	push(@tmpz, "LINE1:B_dn#0000EE");
-	push(@tmpz, "LINE1:B_up#00EE00");
+	push(@tmp, "AREA:B_dn#44EE44:Input");
+	push(@tmp, "AREA:B_up#4444EE:Output");
+	push(@tmp, "AREA:B_up#4444EE:");
+	push(@tmp, "AREA:B_dn#44EE44:");
+	push(@tmp, "LINE1:B_up#0000EE");
+	push(@tmp, "LINE1:B_dn#00EE00");
+	push(@tmpz, "AREA:B_dn#44EE44:Input");
+	push(@tmpz, "AREA:B_up#4444EE:Output");
+	push(@tmpz, "AREA:B_up#4444EE:");
+	push(@tmpz, "AREA:B_dn#44EE44:");
+	push(@tmpz, "LINE1:B_up#0000EE");
+	push(@tmpz, "LINE1:B_dn#00EE00");
 	push(@CDEF, "CDEF:B_up=up");
 	if(lc($config->{netstats_mode} || "") eq "separated") {
 		push(@CDEF, "CDEF:B_dn=dn,-1,*");
@@ -698,7 +701,7 @@ sub ftp_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -721,7 +724,7 @@ sub ftp_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -739,8 +742,8 @@ sub ftp_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG3z, IMG => $IMG3) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
