@@ -437,7 +437,7 @@ sub int_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -976,13 +976,16 @@ sub int_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	my $IMG1 = $u . $package . "1." . $tf->{when} . ".$imgfmt_lc";
 	my $IMG2 = $u . $package . "2." . $tf->{when} . ".$imgfmt_lc";
@@ -1070,7 +1073,7 @@ sub int_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$colors->{graph_colors}},
 		@DEF1,
@@ -1091,7 +1094,7 @@ sub int_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			@DEF1,
@@ -1107,8 +1110,8 @@ sub int_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG1z, IMG => $IMG1) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1148,7 +1151,7 @@ sub int_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1170,7 +1173,7 @@ sub int_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1187,8 +1190,8 @@ sub int_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG2z, IMG => $IMG2) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1224,7 +1227,7 @@ sub int_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1246,7 +1249,7 @@ sub int_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -1263,8 +1266,8 @@ sub int_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG3z, IMG => $IMG3) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
