@@ -357,7 +357,7 @@ sub intelrapl_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -473,13 +473,16 @@ sub intelrapl_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	my $plots_per_list_item = 1;
 	for($n = 0; $n < keys(%{$intelrapl->{list}}); $n++) {
@@ -732,7 +735,7 @@ sub intelrapl_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			$large_plot ? () : @{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -754,7 +757,7 @@ sub intelrapl_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				$large_plot ? () : @{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -772,8 +775,8 @@ sub intelrapl_cgi {
 					push(@output, "      <a href=\"" . $config->{url} . "/" . $config->{imgs_dir} . $IMGz[$e * $plots_per_list_item + $n_plot] . "\"><img src='" . $config->{url} . "/" . $config->{imgs_dir} . $IMG[$e * $plots_per_list_item + $n_plot] . "' border='0'></a>\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
