@@ -630,19 +630,19 @@ sub mail_update {
 		$gen[4] /= 60 if lc($mail->{stats_rate}) eq "per_second";
 	}
 
+	$gen_h[5] = $gen[5] = 0;
+	$gen_h[6] = $gen[6] = 0;
+	$gen_h[7] = $gen[7] = 0;
+	$gen_h[8] = $gen[8] = 0;
+	$gen_h[9] = $gen[9] = 0;
+
 	if(lc($mail->{greylist}) eq "milter-greylist") {
-		$gen_h[5] = $gen[5] = 0;
 		$gen_h[6] = $gen[6] = int($gl_records) || 0;
 		$gen_h[7] = $gen[7] = int($gl_greylisted) || 0;
 		$gen_h[8] = $gen[8] = int($gl_whitelisted) || 0;
 		$gen_h[9] = $gen[9] = int($gl_delayed) || 0;
 	}
 	if(lc($mail->{greylist}) eq "postgrey") {
-		$gen_h[5] = $gen[5] = 0;
-		$gen_h[6] = $gen[6] = 0;
-		$gen_h[7] = $gen[7] = 0;
-		$gen_h[8] = $gen[8] = 0;
-		$gen_h[9] = $gen[9] = 0;
 		# avoid initial peak
 		if(!$first_read) {
 			$gen[6] = int($gl_records);
@@ -731,7 +731,7 @@ sub mail_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -828,13 +828,16 @@ sub mail_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	my $IMG1 = $u . $package . "1." . $tf->{when} . ".$imgfmt_lc";
 	my $IMG2 = $u . $package . "2." . $tf->{when} . ".$imgfmt_lc";
@@ -1102,7 +1105,7 @@ sub mail_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$colors->{graph_colors}},
 		"DEF:in=$rrd:mail_in:AVERAGE",
@@ -1139,7 +1142,7 @@ sub mail_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:in=$rrd:mail_in:AVERAGE",
@@ -1170,8 +1173,8 @@ sub mail_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG1z, IMG => $IMG1) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1244,7 +1247,7 @@ sub mail_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$colors->{graph_colors}},
 		"DEF:in=$rrd:mail_bytes_recvd:AVERAGE",
@@ -1270,7 +1273,7 @@ sub mail_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:in=$rrd:mail_bytes_recvd:AVERAGE",
@@ -1289,8 +1292,8 @@ sub mail_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG2z, IMG => $IMG2) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1338,7 +1341,7 @@ sub mail_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1360,7 +1363,7 @@ sub mail_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1377,8 +1380,8 @@ sub mail_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG3z, IMG => $IMG3) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1422,7 +1425,7 @@ sub mail_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1445,7 +1448,7 @@ sub mail_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1462,8 +1465,8 @@ sub mail_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG4z, IMG => $IMG4) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1514,7 +1517,7 @@ sub mail_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1539,7 +1542,7 @@ sub mail_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1559,8 +1562,8 @@ sub mail_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG5z, IMG => $IMG5) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1628,7 +1631,7 @@ sub mail_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1653,7 +1656,7 @@ sub mail_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1673,8 +1676,8 @@ sub mail_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG6z, IMG => $IMG6) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
