@@ -257,7 +257,7 @@ sub nvidiagpu_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -388,13 +388,16 @@ sub nvidiagpu_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	for($n = 0; $n < keys(%{$nvidiagpu->{list}}); $n++) {
 		for($n2 = 0; $n2 < $number_of_sensor_values_in_use; $n2++) {
@@ -641,7 +644,7 @@ sub nvidiagpu_cgi {
 				"--height=$height",
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				$n_plot < $main_sensor_plots ? () : @{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -663,7 +666,7 @@ sub nvidiagpu_cgi {
 					@full_size_mode,
 					@extra,
 					@riglim,
-					$zoom,
+					$global_zoom,
 					@{$cgi->{version12}},
 					$n_plot < $main_sensor_plots ? () : @{$cgi->{version12_small}},
 					@{$colors->{graph_colors}},
@@ -681,8 +684,8 @@ sub nvidiagpu_cgi {
 						push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * $number_of_sensor_values_in_use + $n_plot], IMG => $IMG[$e * $number_of_sensor_values_in_use + $n_plot]) . "\n");
 					} else {
 						if($version eq "new") {
-							$picz_width = $picz->{image_width} * $config->{global_zoom};
-							$picz_height = $picz->{image_height} * $config->{global_zoom};
+							$picz_width = $picz->{image_width} * $zoom;
+							$picz_height = $picz->{image_height} * $zoom;
 						} else {
 							$picz_width = $width + 115;
 							$picz_height = $height + 100;
