@@ -359,7 +359,7 @@ sub nvme_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -491,13 +491,16 @@ sub nvme_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	# Plot settings in order of the smart array.
 	# Array index is the smart sensor index:
@@ -719,7 +722,7 @@ sub nvme_cgi {
 				@scaling_options,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				$n_plot < $main_smart_plots ? () : @{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -742,7 +745,7 @@ sub nvme_cgi {
 					@full_size_mode,
 					@extra,
 					@riglim,
-					$zoom,
+					$global_zoom,
 					@{$cgi->{version12}},
 					$n_plot < $main_smart_plots ? () : @{$cgi->{version12_small}},
 					@{$colors->{graph_colors}},
@@ -760,8 +763,8 @@ sub nvme_cgi {
 						push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * $number_of_plots + $n_plot], IMG => $IMG[$e * $number_of_plots + $n_plot]) . "\n");
 					} else {
 						if($version eq "new") {
-							$picz_width = $picz->{image_width} * $config->{global_zoom};
-							$picz_height = $picz->{image_height} * $config->{global_zoom};
+							$picz_width = $picz->{image_width} * $zoom;
+							$picz_height = $picz->{image_height} * $zoom;
 						} else {
 							$picz_width = $width + 115;
 							$picz_height = $height + 100;
