@@ -646,7 +646,7 @@ sub pagespeed_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -756,13 +756,16 @@ sub pagespeed_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	for($n = 0; $n < scalar(my @pl = split(',', $pagespeed->{list})); $n++) {
 		for($n2 = 1; $n2 <= 8; $n2++) {
@@ -875,7 +878,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:cahit=$rrd:pagespeed" . $e . "_cahit:AVERAGE",
@@ -905,7 +908,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				"DEF:cahit=$rrd:pagespeed" . $e . "_cahit:AVERAGE",
@@ -931,8 +934,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8], IMG => $IMG[$e * 8]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1011,7 +1014,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:urltri=$rrd:pagespeed" . $e . "_urltri:AVERAGE",
@@ -1038,7 +1041,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				"DEF:urltri=$rrd:pagespeed" . $e . "_urltri:AVERAGE",
@@ -1061,8 +1064,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8 + 1], IMG => $IMG[$e * 8 + 1]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1122,7 +1125,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:cftob=$rrd:pagespeed" . $e . "_cftob:AVERAGE",
@@ -1150,7 +1153,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				"DEF:cftob=$rrd:pagespeed" . $e . "_cftob:AVERAGE",
@@ -1174,8 +1177,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8 + 2], IMG => $IMG[$e * 8 + 2]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1228,7 +1231,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1255,7 +1258,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -1278,8 +1281,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8 + 3], IMG => $IMG[$e * 8 + 3]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1328,7 +1331,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1355,7 +1358,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -1378,8 +1381,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8 + 4], IMG => $IMG[$e * 8 + 4]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1425,7 +1428,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1451,7 +1454,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -1473,8 +1476,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8 + 5], IMG => $IMG[$e * 8 + 5]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1523,7 +1526,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1550,7 +1553,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -1573,8 +1576,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8 + 6], IMG => $IMG[$e * 8 + 6]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1608,7 +1611,7 @@ sub pagespeed_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1630,7 +1633,7 @@ sub pagespeed_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -1648,8 +1651,8 @@ sub pagespeed_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 8 + 7], IMG => $IMG[$e * 8 + 7]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
