@@ -346,7 +346,7 @@ sub redis_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -459,13 +459,16 @@ sub redis_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	for($n = 0; $n < scalar(my @ml = split(',', $redis->{list})); $n++) {
 		for($n2 = 1; $n2 <= 6; $n2++) {
@@ -551,7 +554,7 @@ sub redis_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:tconn=$rrd:redis" . $e . "_tconn:AVERAGE",
@@ -578,7 +581,7 @@ sub redis_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				"DEF:tconn=$rrd:redis" . $e . "_tconn:AVERAGE",
@@ -597,8 +600,8 @@ sub redis_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 6], IMG => $IMG[$e * 6]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -659,7 +662,7 @@ sub redis_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:afrgr=$rrd:redis" . $e . "_afrgr:AVERAGE",
@@ -686,7 +689,7 @@ sub redis_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				"DEF:afrgr=$rrd:redis" . $e . "_afrgr:AVERAGE",
@@ -706,8 +709,8 @@ sub redis_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 6 + 1], IMG => $IMG[$e * 6 + 1]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -760,7 +763,7 @@ sub redis_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -784,7 +787,7 @@ sub redis_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -804,8 +807,8 @@ sub redis_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 6 + 2], IMG => $IMG[$e * 6 + 2]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -850,7 +853,7 @@ sub redis_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -873,7 +876,7 @@ sub redis_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -892,8 +895,8 @@ sub redis_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 6 + 3], IMG => $IMG[$e * 6 + 3]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -941,7 +944,7 @@ sub redis_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -965,7 +968,7 @@ sub redis_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -985,8 +988,8 @@ sub redis_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 6 + 4], IMG => $IMG[$e * 6 + 4]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -1052,7 +1055,7 @@ sub redis_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1075,7 +1078,7 @@ sub redis_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -1094,8 +1097,8 @@ sub redis_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 6 + 5], IMG => $IMG[$e * 6 + 5]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
