@@ -259,6 +259,11 @@ sub serv_update {
 					$sc[3] = "\".\"" unless $sc[3] ne "\"\"";	# set "." as a minimal regex
 					my @regex = split('\+', $sc[3]);
 					my $IN;
+
+					# FIXME
+					# $seek_pos does not distinguish between different
+					# logfiles when a service is defined multiple times.
+
 					my $seek_pos = $config->{serv_hist}->{$seek_str} || 0;
 					if($logfile =~ m/^file:.+/) {
 						$logfile =~ s/^file://;
@@ -352,7 +357,7 @@ sub serv_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -495,13 +500,16 @@ sub serv_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	for($n = 0; $n < scalar(keys %{$serv->{list}}); $n++) {
 		$str = $u . $package . $n . "." . $tf->{when} . ".$imgfmt_lc";
@@ -632,7 +640,7 @@ sub serv_cgi {
 				"--height=$height",
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				@DEF0,
@@ -653,7 +661,7 @@ sub serv_cgi {
 					@full_size_mode,
 					@extra,
 					@riglim,
-					$zoom,
+					$global_zoom,
 					@{$cgi->{version12}},
 					@{$colors->{graph_colors}},
 					@DEF0,
@@ -669,8 +677,8 @@ sub serv_cgi {
 						push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e], IMG => $IMG[$e]) . "\n");
 					} else {
 						if($version eq "new") {
-							$picz_width = $picz->{image_width} * $config->{global_zoom};
-							$picz_height = $picz->{image_height} * $config->{global_zoom};
+							$picz_width = $picz->{image_width} * $zoom;
+							$picz_height = $picz->{image_height} * $zoom;
 						} else {
 							$picz_width = $width + 115;
 							$picz_height = $height + 100;
