@@ -175,57 +175,41 @@ sub tinyproxy_update {
 
 		#print $data->toStringHTML();
 
-		my $xpath = '//tr//td';
-		my @stats;
-
-		# This 'foreach' emulates the method 'to_literal_list' as it was
-		# introduced in Perl-XML-LibXML version 2.0105 (2013-09-07), and
-		# unfortunately not all systems have such a recent version.
-		#
-		# Some day in the future it should be changed by the line:
-		# push(@stats, $_) foreach $data->findnodes($xpath)->to_literal_list;
-		foreach($data->findnodes($xpath)->get_nodelist()) {
-			my $node;
-			($node = $_) =~ s@</?td>@@g;
-			push(@stats, $node);
-		}
-		my %hstats = @stats;
-
-		for my $key (keys %hstats) {
-			if($key eq "Number of open connections") {
+		foreach(split('\n', $data->toStringHTML())) {
+			if(/^Number of open connections:\s+(\d+)/) {
 				$str = $e . "open";
-				$ocon = $hstats{$key} - ($config->{tinyproxy_hist}->{$str} || 0);
-				$ocon = 0 unless $ocon != $hstats{$key};
+				$ocon = $1 - ($config->{tinyproxy_hist}->{$str} || 0);
+				$ocon = 0 unless $ocon != $1;
 				$ocon /= 60;
-				$config->{tinyproxy_hist}->{$str} = $hstats{$key};
+				$config->{tinyproxy_hist}->{$str} = $1;
 			}
-			if($key eq "Number of requests") {
+			if(/Number of requests:\s+(\d+)/) {
 				$str = $e . "reqs";
-				$reqs = $hstats{$key} - ($config->{tinyproxy_hist}->{$str} || 0);
-				$reqs = 0 unless $reqs != $hstats{$key};
+				$reqs = $1 - ($config->{tinyproxy_hist}->{$str} || 0);
+				$reqs = 0 unless $reqs != $1;
 				$reqs /= 60;
-				$config->{tinyproxy_hist}->{$str} = $hstats{$key};
+				$config->{tinyproxy_hist}->{$str} = $1;
 			}
-			if($key eq "Number of bad connections") {
+			if(/Number of bad connections:\s+(\d+)/) {
 				$str = $e . "bcon";
-				$bcon = $hstats{$key} - ($config->{tinyproxy_hist}->{$str} || 0);
-				$bcon = 0 unless $bcon != $hstats{$key};
+				$bcon = $1 - ($config->{tinyproxy_hist}->{$str} || 0);
+				$bcon = 0 unless $bcon != $1;
 				$bcon /= 60;
-				$config->{tinyproxy_hist}->{$str} = $hstats{$key};
+				$config->{tinyproxy_hist}->{$str} = $1;
 			}
-			if($key eq "Number of denied connections") {
+			if(/Number of denied connections:\s+(\d+)/) {
 				$str = $e . "dcon";
-				$dcon = $hstats{$key} - ($config->{tinyproxy_hist}->{$str} || 0);
-				$dcon = 0 unless $dcon != $hstats{$key};
+				$dcon = $1 - ($config->{tinyproxy_hist}->{$str} || 0);
+				$dcon = 0 unless $dcon != $1;
 				$dcon /= 60;
-				$config->{tinyproxy_hist}->{$str} = $hstats{$key};
+				$config->{tinyproxy_hist}->{$str} = $1;
 			}
-			if($key eq "Number of refused connections due to high load") {
+			if(/Number of refused connections due to high load:\s+(\d+)/) {
 				$str = $e . "rcon";
-				$rcon = $hstats{$key} - ($config->{tinyproxy_hist}->{$str} || 0);
-				$rcon = 0 unless $rcon != $hstats{$key};
+				$rcon = $1 - ($config->{tinyproxy_hist}->{$str} || 0);
+				$rcon = 0 unless $rcon != $1;
 				$rcon /= 60;
-				$config->{tinyproxy_hist}->{$str} = $hstats{$key};
+				$config->{tinyproxy_hist}->{$str} = $1;
 			}
 		}
 
@@ -251,7 +235,7 @@ sub tinyproxy_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -358,13 +342,16 @@ sub tinyproxy_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	for($n = 0; $n < scalar(my @tl = split(',', $tinyproxy->{list})); $n++) {
 		for($n2 = 1; $n2 <= 3; $n2++) {
@@ -425,7 +412,7 @@ sub tinyproxy_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:tinyproxy" . $e . "_reqs=$rrd:tinyproxy" . $e . "_reqs:AVERAGE",
@@ -451,7 +438,7 @@ sub tinyproxy_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				"DEF:tinyproxy" . $e . "_reqs=$rrd:tinyproxy" . $e . "_reqs:AVERAGE",
@@ -468,8 +455,8 @@ sub tinyproxy_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 3], IMG => $IMG[$e * 3]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -515,7 +502,7 @@ sub tinyproxy_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -537,7 +524,7 @@ sub tinyproxy_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -555,8 +542,8 @@ sub tinyproxy_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 3 + 1], IMG => $IMG[$e * 3 + 1]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
@@ -604,7 +591,7 @@ sub tinyproxy_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -628,7 +615,7 @@ sub tinyproxy_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$cgi->{version12_small}},
 				@{$colors->{graph_colors}},
@@ -648,8 +635,8 @@ sub tinyproxy_cgi {
 					push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e * 3 + 2], IMG => $IMG[$e * 3 + 2]) . "\n");
 				} else {
 					if($version eq "new") {
-						$picz_width = $picz->{image_width} * $config->{global_zoom};
-						$picz_height = $picz->{image_height} * $config->{global_zoom};
+						$picz_width = $picz->{image_width} * $zoom;
+						$picz_height = $picz->{image_height} * $zoom;
 					} else {
 						$picz_width = $width + 115;
 						$picz_height = $height + 100;
