@@ -496,7 +496,7 @@ sub traffacct_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -546,13 +546,16 @@ sub traffacct_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	for($n = 0; $n < $traffacct->{max}; $n++) {
 		$str = $u . "traffacct" . $n . ".$tf->{when}" . ".$imgfmt_lc";
@@ -622,7 +625,7 @@ sub traffacct_cgi {
 					"--height=$height",
 					@extra,
 					@riglim,
-					$zoom,
+					$global_zoom,
 					@{$cgi->{version12}},
 					@{$cgi->{version12_small}},
 					@{$colors->{graph_colors}},
@@ -645,7 +648,7 @@ sub traffacct_cgi {
 						@full_size_mode,
 						@extra,
 						@riglim,
-						$zoom,
+						$global_zoom,
 						@{$cgi->{version12}},
 						@{$cgi->{version12_small}},
 						@{$colors->{graph_colors}},
@@ -662,8 +665,8 @@ sub traffacct_cgi {
 						print("      " . picz_a_element(config => $config, IMGz => $IMGz[$n], IMG => $IMG[$n]) . "\n");
 					} else {
 						if($version eq "new") {
-							$picz_width = $picz->{image_width} * $config->{global_zoom};
-							$picz_height = $picz->{image_height} * $config->{global_zoom};
+							$picz_width = $picz->{image_width} * $zoom;
+							$picz_height = $picz->{image_height} * $zoom;
 						} else {
 							$picz_width = $width + 115;
 							$picz_height = $height + 100;
@@ -736,7 +739,7 @@ sub traffacct_cgi {
 			"--height=$height",
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:in=$rrd:traffacct" . $cgi->{val} . "_in:AVERAGE",
@@ -760,7 +763,7 @@ sub traffacct_cgi {
 				@full_size_mode,
 				@extra,
 				@riglim,
-				$zoom,
+				$global_zoom,
 				@{$cgi->{version12}},
 				@{$colors->{graph_colors}},
 				"DEF:in=$rrd:traffacct" . $cgi->{val} . "_in:AVERAGE",
@@ -778,8 +781,8 @@ sub traffacct_cgi {
 				print("      " . picz_a_element(config => $config, IMGz => $IMGz[$cgi->{val}], IMG => $IMG[$cgi->{val}]) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
