@@ -405,7 +405,7 @@ sub zfs_cgi {
 	my $colors = $cgi->{colors};
 	my $graph = $cgi->{graph};
 	my $silent = $cgi->{silent};
-	my $zoom = "--zoom=" . $config->{global_zoom};
+	my $zoom = $config->{global_zoom};
 	my %rrd = (
 		'new' => \&RRDs::graphv,
 		'old' => \&RRDs::graph,
@@ -512,13 +512,16 @@ sub zfs_cgi {
 	# graph mode
 	#
 	if($silent eq "yes" || $silent eq "imagetag") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "_";
 	}
 	if($silent eq "imagetagbig") {
+		$zoom = 1;	# force 'global_zoom' to 1 in Multihost viewer
 		$colors->{fg_color} = "#000000";  # visible color for text mode
 		$u = "";
 	}
+	my $global_zoom = "--zoom=" . $zoom;
 
 	my $IMG1 = $u . $package . "1." . $tf->{when} . ".$imgfmt_lc";
 	my $IMG2 = $u . $package . "2." . $tf->{when} . ".$imgfmt_lc";
@@ -618,7 +621,7 @@ sub zfs_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$colors->{graph_colors}},
 		"DEF:arcsize=$rrd:zfs_arcsize:AVERAGE",
@@ -646,7 +649,7 @@ sub zfs_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$colors->{graph_colors}},
 			"DEF:arcsize=$rrd:zfs_arcsize:AVERAGE",
@@ -668,8 +671,8 @@ sub zfs_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG1z, IMG => $IMG1) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -721,7 +724,7 @@ sub zfs_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -745,7 +748,7 @@ sub zfs_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -764,8 +767,8 @@ sub zfs_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG2z, IMG => $IMG2) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -810,7 +813,7 @@ sub zfs_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -833,7 +836,7 @@ sub zfs_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -851,8 +854,8 @@ sub zfs_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMG3z, IMG => $IMG3) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -910,7 +913,7 @@ sub zfs_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -934,7 +937,7 @@ sub zfs_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -953,8 +956,8 @@ sub zfs_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e], IMG => $IMG[$e]) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1000,7 +1003,7 @@ sub zfs_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1023,7 +1026,7 @@ sub zfs_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1041,8 +1044,8 @@ sub zfs_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e], IMG => $IMG[$e]) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1092,7 +1095,7 @@ sub zfs_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1116,7 +1119,7 @@ sub zfs_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1135,8 +1138,8 @@ sub zfs_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e], IMG => $IMG[$e]) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
@@ -1182,7 +1185,7 @@ sub zfs_cgi {
 		"--height=$height",
 		@extra,
 		@riglim,
-		$zoom,
+		$global_zoom,
 		@{$cgi->{version12}},
 		@{$cgi->{version12_small}},
 		@{$colors->{graph_colors}},
@@ -1208,7 +1211,7 @@ sub zfs_cgi {
 			@full_size_mode,
 			@extra,
 			@riglim,
-			$zoom,
+			$global_zoom,
 			@{$cgi->{version12}},
 			@{$cgi->{version12_small}},
 			@{$colors->{graph_colors}},
@@ -1229,8 +1232,8 @@ sub zfs_cgi {
 				push(@output, "      " . picz_a_element(config => $config, IMGz => $IMGz[$e], IMG => $IMG[$e]) . "\n");
 			} else {
 				if($version eq "new") {
-					$picz_width = $picz->{image_width} * $config->{global_zoom};
-					$picz_height = $picz->{image_height} * $config->{global_zoom};
+					$picz_width = $picz->{image_width} * $zoom;
+					$picz_height = $picz->{image_height} * $zoom;
 				} else {
 					$picz_width = $width + 115;
 					$picz_height = $height + 100;
